@@ -86,7 +86,7 @@ from typing import AnyStr, Optional, Tuple, Union, Mapping, Any, List, TypeVar,
 from typing import get_type_hints
 
 from ..lib.frame import Chunk
-from ..lib.tools import isbuffer
+from ..lib.tools import isbuffer, infinitize
 from ..lib.loader import resolve, EntryNotFound
 
 FinalType = TypeVar('FinalType')
@@ -96,7 +96,7 @@ MaybeDelayedType = Union[DelayedType[FinalType], FinalType]
 
 
 class ParserError(ArgumentTypeError): pass
-class VariablesMissing(ParserError): pass
+class ParserVariableMissing(ParserError): pass
 
 
 class RepeatedInteger(int):
@@ -186,7 +186,7 @@ class PythonExpression:
                     ', '.join(t.__name__ for t in types - self._ALLOWED_NODE_TYPES))
             )
         if not all_variables_allowed and not names <= variables:
-            raise VariablesMissing(
+            raise ParserVariableMissing(
                 'the following variable names are unknown: {}'.format(
                     ', '.join(names - variables))
             )
@@ -210,7 +210,7 @@ class PythonExpression:
         return expression(**values)
 
 
-def sliceobj(expression: Union[int, str, slice], **variables) -> slice:
+def sliceobj(expression: Union[int, str, slice], variables: Optional[dict] = None, range=False) -> slice:
     """
     Uses `refinery.lib.argformats.PythonExpression` to parse slice expressions
     where the bounds can be given as arithmetic expressions. For example, this
@@ -226,14 +226,20 @@ def sliceobj(expression: Union[int, str, slice], **variables) -> slice:
         if not sliced or len(sliced) > 3:
             raise ArgumentTypeError(F'the expression {expression} is not a valid slice.')
         try:
-            sliced = [None if not t else PythonExpression.evaluate(t, **variables) for t in sliced]
-        except VariablesMissing:
+            kwargs = variables or {}
+            sliced = [None if not t else PythonExpression.evaluate(t, **kwargs) for t in sliced]
+        except ParserVariableMissing:
             class SliceAgain(LazyEvaluation):
-                def __call__(self, data): return sliceobj(expression, **data.meta)
+                def __call__(self, data):
+                    return sliceobj(expression, data.meta)
+            if variables is not None:
+                raise
             return SliceAgain()
     if len(sliced) == 1:
         k = sliced[0]
-        return slice(k, k + 1) if k + 1 else slice(k, None, None)
+        if not range:
+            return slice(k, k + 1) if k + 1 else slice(k, None, None)
+        return slice(0, k)
     return slice(*sliced)
 
 
@@ -535,15 +541,22 @@ class DelayedArgument(LazyEvaluation):
         `bounds` is just a single integer, it is interpreted as the upper bound for a sequence
         of bytes starting at zero.
         """
+        def compute_range(data: Optional[Chunk] = None):
+            meta = data and getattr(data, 'meta', None) or {}
+            bounds = sliceobj(region, meta, range=True)
+            start = bounds.start or 0
+            stop = bounds.stop
+            step = bounds.step or 1
+            if stop is None:
+                return itertools.islice(itertools.count(), start, None, step)
+            result = range(start, stop, step)
+            if 0 <= start and stop <= 0x100:
+                result = bytearray(result)
+            return result
         try:
-            bounds = number(region)
-            return bytearray(range(bounds))
-        except (ValueError, ArgumentTypeError):
-            pass
-        bounds = sliceobj(region)
-        if bounds.stop is None:
-            raise ArgumentTypeError('cannot generate unbounded byte sequence.')
-        return bytearray(range(bounds.start or 0, bounds.stop, bounds.step or 1))
+            return compute_range()
+        except ParserVariableMissing:
+            return compute_range
 
     @handler.register('c', 'copy', final=True)
     def copy(self, region: str) -> bytes:
@@ -552,7 +565,7 @@ class DelayedArgument(LazyEvaluation):
         as a `refinery.lib.argformats.sliceobj`. The result contains the corresponding slice
         of the input data.
         """
-        return lambda d: memoryview(d)[sliceobj(region, **d.meta)]
+        return lambda d: memoryview(d)[sliceobj(region, d.meta)]
 
     @handler.register('x', 'cut', final=True)
     def cut(self, region: str) -> bytes:
@@ -565,7 +578,7 @@ class DelayedArgument(LazyEvaluation):
                 meta = data.meta
             except AttributeError:
                 meta = {}
-            bounds = sliceobj(region, **meta)
+            bounds = sliceobj(region, meta)
             result = bytearray(data[bounds])
             data[bounds] = []
             return result
@@ -686,7 +699,7 @@ class DelayedArgument(LazyEvaluation):
         """
         def delay(_):
             k = itertools.cycle(range(number(wrap))) if wrap else itertools.count()
-            for item in itertools.cycle(it):
+            for item in infinitize(it):
                 yield item + next(k)
         return delay
 
@@ -698,7 +711,7 @@ class DelayedArgument(LazyEvaluation):
         """
         def delay(_):
             k = itertools.cycle(range(number(wrap))) if wrap else itertools.count()
-            for item in itertools.cycle(it):
+            for item in infinitize(it):
                 yield item - next(k)
         return delay
 
@@ -707,7 +720,7 @@ class DelayedArgument(LazyEvaluation):
         """
         The handler `take[start:stop:step]` expects an integer sequence as input and applies a slice
         to it. Slices are given in Python syntax, so `take[::2]` will extract every second item from
-        the incoming data.
+        the incoming data. The default sequence is `1:`, i.e. skipping the first element.
         """
         bounds = bounds and sliceobj(bounds) or slice(1, None)
         try:
@@ -834,6 +847,8 @@ class DelayedNumSeqArgument(DelayedArgument):
 
     def __call__(self, data: Optional[Union[ByteString, Chunk]] = None) -> Iterable[int]:
         value = super().__call__(data)
+        if isbuffer(value):
+            return value
         if hasattr(value, '__iter__'):
             try:
                 if len(value) == 1:
@@ -1011,7 +1026,7 @@ def numseq(expression: Union[int, str]) -> Union[Iterable[int], DelayedNumSeqArg
     This is the argument parser type that uses `refinery.lib.argformats.DelayedNumSeqArgument`.
     """
     if isinstance(expression, int):
-        return (expression,)
+        return RepeatedInteger(expression)
     arg = DelayedNumSeqArgument(expression)
     with suppress(TooLazy):
         return arg()
