@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 import olefile
 
-from . import PathExtractorUnit, UnpackResult
-from ...lib.structures import MemoryFile
+from .. import PathExtractorUnit, UnpackResult
+from ....lib.structures import MemoryFile
 
 
 class xtdoc(PathExtractorUnit):
@@ -17,7 +17,7 @@ class xtdoc(PathExtractorUnit):
                 oledoc = olefile.OleFileIO(stream)
             except OSError as error:
                 self.log_info(F'error, {error}, treating input as zip file')
-                from .xtzip import xtzip
+                from ..xtzip import xtzip
                 yield from xtzip().unpack(data)
                 return
             for item in oledoc.listdir():
