@@ -34,10 +34,10 @@ class perc(PathExtractorUnit):
     Extract PE file resources.
     """
     def __init__(self, *paths, list=False, join=False, regex=False, meta=b'path'):
-        def fixpath(p):
+        def fixpath(p: str):
             if regex or not p.isidentifier():
                 return p
-            return re.compile(FR'^.*?\b{re.escape(p)}\b.*$')
+            return re.compile(FR'^.*?{re.escape(p)}.*$')
         super().__init__(*(fixpath(p) for p in paths), list=list, join=join)
 
     def _search(self, pe, directory, level=0, *parts):
