@@ -1,8 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+import itertools
+
 from .. import arg, Unit
 from ...lib.argformats import numseq
 from ...lib.tools import isbuffer
+from . import check_variable_name
 
 
 class put(Unit):
@@ -15,15 +18,20 @@ class put(Unit):
         name : arg(help='The name of the variable to be used.', type=str),
         value: arg(help='The value for the variable.', type=numseq)
     ):
-        super().__init__(name=name, value=value)
+        super().__init__(name=check_variable_name(name), value=value)
 
     def process(self, data):
         value = self.args.value
-        if not isbuffer(value):
-            if isinstance(value, (list, tuple, set)):
-                if len(value) == 1:
-                    value = next(iter(value))
-            elif not isinstance(value, int):
-                raise NotImplementedError('metadata can currently not handle unbounded integer iterables.')
+        if not isinstance(value, int) and not isbuffer(value):
+            try:
+                len(value)
+            except TypeError:
+                if isinstance(value, itertools.repeat):
+                    value = next(value)
+                if not isinstance(value, int):
+                    raise NotImplementedError(F'Unsupported value {value!r}; expected integer.')
+            else:
+                if not isinstance(value, list):
+                    value = list(value)
         self.log_debug(F'storing {type(value).__name__}:', value)
         return self.labelled(data, **{self.args.name: value})
